############################################
# Purpose:
# This script takes a list of variables and outputs all the additional variables that need to keep the same type.
#
# Inputs:
#
#    -v, --vault : Path to the vault.
#    -i, --input-list: path to input variable list
#    -o, --output-list : name of output variable list
#
############################################
from AutoRPE.UtilsRPE.Functions import load_vault, save_variable_list, load_variable_list


if __name__ == "__main__":
    # Getting Command line options
    from optparse import OptionParser
    parser = OptionParser()
    parser.add_option("-v", "--vault", dest="vault_path", default=None, metavar="FILE")
    parser.add_option("-i", "--input-list", dest="path_input_list", default=None, metavar="FILE")
    parser.add_option("-o", "--output-list", dest="path_to_output_list", default="list_of_additional_var.txt", metavar="FILE")

    (options, args) = parser.parse_args()
    vault_path = options.vault_path
    path_to_input_list = options.path_input_list
    path_to_output_list = options.path_to_output_list

    if path_to_input_list is None or vault_path is None:
       print("\nThe arguments -s/--input-source and -v/--vault are mandatory\n")
       parser.print_help()
       exit(1)

    # Load vault
    vault = load_vault(vault_path)

    # Load list of variables
    list_of_variable_ids = load_variable_list(path_to_input_list)

    # Initialize empty list of additional variables
    list_of_additional_variable_ids = []

    # Loop over input list of variables
    for _id in list_of_variable_ids:
        # Obtain variable object from id
        var = vault.get_variable_by_id(_id)
        # Loop over variables that are in the object .same_as list.
        for additional_var in var.same_as:
            # If the variable has an id, add it to the additional var list.
            if additional_var.id:
                list_of_additional_variable_ids.append(additional_var.id)

    # Keep unique values
    all_variables = list(set(list_of_additional_variable_ids + list_of_variable_ids))

    # Save variable list
    save_variable_list(all_variables, path_to_output_list, vault)
