############################################
# Purpose:
# This script takes a vault and creates a namelist_precisions for that vault.
#
# Inputs:
#
#    -v, --vault : Path to the vault.
#    -o, --output-namelist : name of output namelist to specify the precision of each variable.
#
############################################


def set_precision_to(value, _vault):
    """
    Function to loop over all variables where we can change the precision to set the precision value.
    """
    for variable in _vault.variables:
        if variable.mutable:
            variable.precision = value


if __name__ == "__main__":
    # Import  load vault
    from AutoRPE.UtilsRPE.Functions import load_vault

    # Read command line parameters
    from optparse import OptionParser
    parser = OptionParser()
    parser.add_option("-v", "--vault", dest="vault", default=None, metavar="FILE",
                      help="Path to the vault database")
    parser.add_option("-o", "--output-namelist", dest="output", default="namelist_precisions", metavar="FILE",
                      help="Filename for the output namelist. Default=namelist_precisions")

    (options, args) = parser.parse_args()
    vault_path = options.vault
    output_filename = options.output

    if vault_path is None:
        print("\nArgument -v/--vault is mandatory\n")
        parser.print_help()
        exit(1)

    # Load vault
    vault = load_vault(vault_path)

    if not vault:
        print("Not able to load %s !\nUnable to create namelist!" % vault_path)
        exit(1)

    # Change the precision of all the vault variables to 52 ( the number of significant bits of a double precision real)
    set_precision_to(52, vault)

    # Generate the namelist
    vault.generate_namelist_precisions(filename=output_filename, exclude_double_precision=False)
